Plugin system for reformat transformers
This crate provides the foundation for loading and managing custom transformation plugins.
Structs
- Plugin
Manager - Plugin API placeholder for future implementation
Plugin system for reformat transformers
This crate provides the foundation for loading and managing custom transformation plugins.